[Pcsclite-cvs-commit] r6950 - trunk/PCSC/src

ludovic.rousseau at free.fr ludovic.rousseau at free.fr
Wed Aug 6 21:01:43 UTC 2014


Author: rousseau
Date: 2014-08-06 21:01:43 +0000 (Wed, 06 Aug 2014)
New Revision: 6950

Modified:
   trunk/PCSC/src/utils.c
Log:
Adjust the thread stack size

The size of 4 MB is not needed and too big (see revision 6948).
By default the thread stack size is:
- 8 MB on Debian GNU/Linux
- 256 KB on Mac OS X 10.9
- 80 KB on musl, but it is not enough for pcsc-lite

256 KB (like on Mac OS X 10.9) is enough for musl.


Modified: trunk/PCSC/src/utils.c
===================================================================
--- trunk/PCSC/src/utils.c	2014-08-06 14:26:41 UTC (rev 6949)
+++ trunk/PCSC/src/utils.c	2014-08-06 21:01:43 UTC (rev 6950)
@@ -167,14 +167,14 @@
 	if (ret)
 		goto error;
 
 	/* stack size of 0x400000 (4 MB) bytes minimum for musl C lib */
 	ret = pthread_attr_getstacksize(&attr, &stack_size);
 	if (ret)
 		goto error;
 
-	if (stack_size < 0x400000)
+	if (stack_size < 0x40000)
 	{
-		stack_size = 0x400000;
+		stack_size = 0x40000;
 		ret = pthread_attr_setstacksize(&attr, stack_size);
 		if (ret)
 			goto error;
@@ -167,14 +167,14 @@
 		goto error;
 
-	/* stack size of 0x400000 (4 MB) bytes minimum for musl C lib */
+	/* stack size of 0x40000 (256 KB) bytes minimum for musl C lib */
 	ret = pthread_attr_getstacksize(&attr, &stack_size);
 	if (ret)




More information about the Pcsclite-cvs-commit mailing list